@@ -1,5 +1,8 @@
-// Process For Playlists
-use aspotify::{Client, PlaylistItemType, Track};
+use rspotify::ClientCredsSpotify;
+use futures::stream::TryStreamExt;
+use futures_util::pin_mut;
+use rspotify::clients::BaseClient;
+use rspotify::model::{FullTrack, Id, PlaylistId, PlayableItem};
 
 use crate::spotify::Song;
 
@@ -12,7 +15,8 @@ fn generate_blank() -> Song {
     }
 }
 
-fn make_song(track: Track) -> Song {
+// NEED TO CHANGE
+fn make_song(track: FullTrack) -> Song {
     let artists = track.artists;
     let image = track.album.images[0].url.to_string();
     let album_name = track.album.name;
@@ -28,27 +32,20 @@ fn make_song(track: Track) -> Song {
     }
 }
 
-pub async fn get_songs(client: Client, playlist_id: String) -> Vec<Song> {
-    let tracks = client
-        .playlists()
-        .get_playlist(&playlist_id, None)
-        .await
-        .unwrap()
-        .data
-        .tracks;
-
+pub async fn songs(client: ClientCredsSpotify, playlist_id: String) -> Vec<Song> {
+    let id = PlaylistId::from_id(&playlist_id).unwrap();
+    let playlist = client.playlist_items(&id, Option::from(""), None);
+    pin_mut!(playlist);
     let mut songs: Vec<Song> = vec![];
-    for track in tracks.items.iter() {
-        let song = match track.to_owned().item {
-            Some(track_item) => match track_item {
-                PlaylistItemType::Track(r) => make_song(r),
-                PlaylistItemType::Episode(_r) => generate_blank(),
-            },
-            None => generate_blank()
+    while let Some(item) = playlist.try_next().await.unwrap() {
+        let song = match item.track.unwrap() {
+            PlayableItem::Track(s) => make_song(s),
+            PlayableItem::Episode(_s) => generate_blank(),
         };
         if song.title != "" {
             songs.push(song);
         }
-    };
+    }
     return songs;
-}
+
+}
\ No newline at end of file
