@@ -1,14 +1,17 @@
-use id3::{Tag, TagLike, Version};
-use id3::frame::{Picture, PictureType};
 use crate::spotify::Song;
+use id3::frame::{Picture, PictureType};
+use id3::{Tag, TagLike, Version};
 
 async fn get_image(image_url: String) -> Vec<u8> {
-    let response = reqwest::get(image_url).await.expect("Something bad happened");
+    let response = reqwest::get(image_url)
+        .await
+        .expect("Something bad happened");
     let image = response.bytes().await.expect("Something bad happened");
     return image.to_vec();
 }
 
 pub async fn generate_id3_tag(song: Song, file_name: String) {
+    println!("{}", file_name);
     let mut tag = Tag::new();
     let album_name = song.album.to_string();
     tag.set_title(song.title);
@@ -20,5 +23,6 @@ pub async fn generate_id3_tag(song: Song, file_name: String) {
         description: album_name,
         data: get_image(song.img).await,
     });
-    tag.write_to_path(file_name, Version::Id3v24).expect("Failed to write id3");
+    tag.write_to_path(file_name, Version::Id3v24)
+        .expect("Failed to write id3");
 }
